@@ -103,12 +103,12 @@ public:
         }
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         return mFrontItems.count() + QSortFilterProxyModel::rowCount(parent) + mBackItems.count();
     }
 
-    QModelIndex mapToSource(const QModelIndex &index) const Q_DECL_OVERRIDE
+    QModelIndex mapToSource(const QModelIndex &index) const override
     {
         if (!isCustomItem(index.row())) {
             const int row = index.row() - mFrontItems.count();
@@ -119,13 +119,13 @@ public:
         }
     }
 
-    QModelIndex mapFromSource(const QModelIndex &source_index) const Q_DECL_OVERRIDE
+    QModelIndex mapFromSource(const QModelIndex &source_index) const override
     {
         const QModelIndex idx = QSortFilterProxyModel::mapFromSource(source_index);
         return createIndex(mFrontItems.count() + idx.row(), idx.column(), idx.internalPointer());
     }
 
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
     {
         if (row < 0 || row >= rowCount()) {
             return QModelIndex();
@@ -140,19 +140,19 @@ public:
         }
     }
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE
+    Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         Q_UNUSED(index);
         return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemNeverHasChildren;
     }
 
-    QModelIndex parent(const QModelIndex &) const Q_DECL_OVERRIDE
+    QModelIndex parent(const QModelIndex &) const override
     {
         // Flat list
         return QModelIndex();
     }
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid()) {
             return QVariant();
@@ -185,15 +185,16 @@ public:
             QString name, email;
 
             if (key.protocol() == GpgME::OpenPGP) {
-                name = userID.name();
-                email = userID.email();
+                name = QString::fromUtf8(userID.name());
+                email = QString::fromUtf8(userID.email());
             } else {
                 const Kleo::DN dn(userID.id());
                 name = dn[QStringLiteral("CN")];
                 email = dn[QStringLiteral("EMAIL")];
             }
-            return i18nc("Name <email> (type, created: date)", "%1 (%2, created: %3)",
+            return i18nc("Name <email> (validity, type, created: date)", "%1 (%2, %3, created: %4)",
                          email.isEmpty() ? name : name.isEmpty() ? email : i18nc("Name <email>", "%1 <%2>", name, email),
+                         Kleo::Formatting::complianceStringShort(key),
                          key.protocol() == GpgME::OpenPGP ? i18n("OpenPGP") : i18n("S/MIME"),
                          Kleo::Formatting::creationDateString(key));
         }
@@ -330,7 +331,7 @@ void Kleo::KeySelectionCombo::setCurrentKey(const QString &fingerprint)
     for (int i = 0; i < d->proxyModel->rowCount(); ++i) {
         const auto idx = d->proxyModel->index(i, 0, QModelIndex());
         const auto key = d->proxyModel->data(idx, Kleo::KeyListModelInterface::KeyRole).value<GpgME::Key>();
-        if (!key.isNull() && fingerprint == key.primaryFingerprint()) {
+        if (!key.isNull() && fingerprint == QString::fromLatin1(key.primaryFingerprint())) {
             setCurrentIndex(i);
             return;
         }
